@@ -5,7 +5,7 @@ use strict;
 
 use Carp;
 use UNIVERSAL::require;
-use YAML;
+use YAML::XS ();
 
 use Test::Run::Base;
 
@@ -20,11 +20,11 @@ Test::Run::CmdLine - Analyze tests from the command line using Test::Run
 
 use vars (qw($VERSION));
 
-$VERSION = '0.0112';
+$VERSION = '0.0120';
 
-use vars (qw(@ISA));
+use Moose;
 
-@ISA = (qw(Test::Run::Base));
+extends ('Test::Run::Base');
 
 =head1 SYNOPSIS
 
@@ -40,13 +40,11 @@ use vars (qw(@ISA));
 
 =cut
 
-__PACKAGE__->mk_accessors(qw(
-    backend_class
-    backend_params
-    backend_plugins
-    backend_env_args
-    test_files
-));
+has 'backend_class' => (is => "rw", isa => "Str");
+has 'backend_params' => (is => "rw", isa => "HashRef");
+has 'backend_plugins' => (is => "rw", isa => "ArrayRef");
+has 'backend_env_args' => (is => "rw", isa => "ArrayRef");
+has 'test_files' => (is => "rw", isa => "ArrayRef");
 
 sub _init
 {
@@ -345,7 +343,7 @@ sub _backend_spec_handler_for_yamldata
     my $env = $spec->{env};
 
     push @{$self->backend_env_args()},
-         ($arg => YAML::LoadFile($ENV{$env}));
+         ($arg => YAML::XS::LoadFile($ENV{$env}));
 }
 
 sub _calc_backend_env_var_map
